From 4aff6e32127e0718c15f839e380a7e26fc4f7b02 Mon Sep 17 00:00:00 2001
From: smorlat <smorlat@3f6dc0c8-ddfe-455d-9043-3cd528dc4637>
Date: Mon, 31 Aug 2009 14:45:51 +0000
Subject: [PATCH] use automake-1.10 when possible render autogen.sh
 mac-compatible.

git-svn-id: svn+ssh://svn.savannah.nongnu.org/linphone/trunk@614 3f6dc0c8-ddfe-455d-9043-3cd528dc4637
---
 linphone/INSTALL                   | 17 +++--------------
 linphone/autogen.sh                | 22 ++++++++++++++++------
 linphone/mediastreamer2/INSTALL    | 17 +++--------------
 linphone/mediastreamer2/autogen.sh |  4 ++--
 linphone/oRTP/autogen.sh           |  4 ++--
 linphone/po/Makefile.in.in         |  4 ++--
 linphone/po/POTFILES.in            |  2 +-
 7 files changed, 29 insertions(+), 41 deletions(-)

diff --git a/linphone/INSTALL b/linphone/INSTALL
index 2550dab752..8b82ade08e 100644
--- a/linphone/INSTALL
+++ b/linphone/INSTALL
@@ -2,7 +2,7 @@ Installation Instructions
 *************************
 
 Copyright (C) 1994, 1995, 1996, 1999, 2000, 2001, 2002, 2004, 2005,
-2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+2006, 2007, 2008 Free Software Foundation, Inc.
 
    This file is free documentation; the Free Software Foundation gives
 unlimited permission to copy, distribute and modify it.
@@ -159,7 +159,7 @@ Particular systems
 CC is not installed, it is recommended to use the following options in
 order to use an ANSI C compiler:
 
-     ./configure CC="cc -Ae -D_XOPEN_SOURCE=500"
+     ./configure CC="cc -Ae"
 
 and if that doesn't work, install pre-built binaries of GCC for HP-UX.
 
@@ -174,16 +174,6 @@ and if that doesn't work, try
 
      ./configure CC="cc -nodtk"
 
-   On Solaris, don't put `/usr/ucb' early in your `PATH'.  This
-directory contains several dysfunctional programs; working variants of
-these programs are available in `/usr/bin'.  So, if you need `/usr/ucb'
-in your `PATH', put it _after_ `/usr/bin'.
-
-   On Haiku, software installed for all users goes in `/boot/common',
-not `/usr/local'.  It is recommended to use the following options:
-
-     ./configure --prefix=/boot/common
-
 Specifying the System Type
 ==========================
 
@@ -199,8 +189,7 @@ type, such as `sun4', or a canonical name which has the form:
 
 where SYSTEM can have one of these forms:
 
-     OS
-     KERNEL-OS
+     OS KERNEL-OS
 
    See the file `config.sub' for the possible values of each field.  If
 `config.sub' isn't included in this package, then this package doesn't
diff --git a/linphone/mediastreamer2/INSTALL b/linphone/mediastreamer2/INSTALL
index 2550dab752..8b82ade08e 100644
--- a/linphone/mediastreamer2/INSTALL
+++ b/linphone/mediastreamer2/INSTALL
@@ -2,7 +2,7 @@ Installation Instructions
 *************************
 
 Copyright (C) 1994, 1995, 1996, 1999, 2000, 2001, 2002, 2004, 2005,
-2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+2006, 2007, 2008 Free Software Foundation, Inc.
 
    This file is free documentation; the Free Software Foundation gives
 unlimited permission to copy, distribute and modify it.
@@ -159,7 +159,7 @@ Particular systems
 CC is not installed, it is recommended to use the following options in
 order to use an ANSI C compiler:
 
-     ./configure CC="cc -Ae -D_XOPEN_SOURCE=500"
+     ./configure CC="cc -Ae"
 
 and if that doesn't work, install pre-built binaries of GCC for HP-UX.
 
@@ -174,16 +174,6 @@ and if that doesn't work, try
 
      ./configure CC="cc -nodtk"
 
-   On Solaris, don't put `/usr/ucb' early in your `PATH'.  This
-directory contains several dysfunctional programs; working variants of
-these programs are available in `/usr/bin'.  So, if you need `/usr/ucb'
-in your `PATH', put it _after_ `/usr/bin'.
-
-   On Haiku, software installed for all users goes in `/boot/common',
-not `/usr/local'.  It is recommended to use the following options:
-
-     ./configure --prefix=/boot/common
-
 Specifying the System Type
 ==========================
 
@@ -199,8 +189,7 @@ type, such as `sun4', or a canonical name which has the form:
 
 where SYSTEM can have one of these forms:
 
-     OS
-     KERNEL-OS
+     OS KERNEL-OS
 
    See the file `config.sub' for the possible values of each field.  If
 `config.sub' isn't included in this package, then this package doesn't
diff --git a/linphone/po/Makefile.in.in b/linphone/po/Makefile.in.in
index 57ef267b3e..402a25f7ac 100644
--- a/linphone/po/Makefile.in.in
+++ b/linphone/po/Makefile.in.in
@@ -21,7 +21,7 @@ GETTEXT_PACKAGE = @GETTEXT_PACKAGE@
 PACKAGE = @PACKAGE@
 VERSION = @VERSION@
 
-SHELL = /bin/sh
+SHELL = @SHELL@
 
 srcdir = @srcdir@
 top_srcdir = @top_srcdir@
@@ -56,7 +56,7 @@ ALL_LINGUAS = @ALL_LINGUAS@
 
 PO_LINGUAS=$(shell if test -r $(srcdir)/LINGUAS; then grep -v "^\#" $(srcdir)/LINGUAS; else echo "$(ALL_LINGUAS)"; fi)
 
-USER_LINGUAS=$(shell if test -n "$(LINGUAS)"; then LLINGUAS="$(LINGUAS)"; ALINGUAS="$(ALL_LINGUAS)"; for lang in $$LLINGUAS; do if test -n "`grep ^$$lang$$ $(srcdir)/LINGUAS 2>/dev/null`" -o -n "`echo $$ALINGUAS|tr ' ' '\n'|grep ^$$lang$$`"; then printf "$$lang "; fi; done; fi)
+USER_LINGUAS=$(shell if test -n "$(LINGUAS)"; then LLINGUAS="$(LINGUAS)"; ALINGUAS="$(ALL_LINGUAS)"; for lang in $$LLINGUAS; do if test -n "`grep \^$$lang$$ $(srcdir)/LINGUAS 2>/dev/null`" -o -n "`echo $$ALINGUAS|tr ' ' '\n'|grep \^$$lang$$`"; then printf "$$lang "; fi; done; fi)
 
 USE_LINGUAS=$(shell if test -n "$(USER_LINGUAS)" -o -n "$(LINGUAS)"; then LLINGUAS="$(USER_LINGUAS)"; else if test -n "$(PO_LINGUAS)"; then LLINGUAS="$(PO_LINGUAS)"; else LLINGUAS="$(ALL_LINGUAS)"; fi; fi; for lang in $$LLINGUAS; do printf "$$lang "; done)
 
diff --git a/linphone/po/POTFILES.in b/linphone/po/POTFILES.in
index bdbfef4fde..eff2a295b3 100644
--- a/linphone/po/POTFILES.in
+++ b/linphone/po/POTFILES.in
@@ -46,7 +46,7 @@ mediastreamer2/src/msspeex.c
 mediastreamer2/src/msvolume.c
 mediastreamer2/src/msv4l.c
 mediastreamer2/src/msv4l2.c
-mediastreamer2/src/msv4m.c
+mediastreamer2/src/msv4m.m
 mediastreamer2/src/nowebcam.c
 mediastreamer2/src/oss.c
 mediastreamer2/src/pixconv.c
diff --git a/linphone/autogen.sh b/linphone/autogen.sh
index c634d61859..2c045ebde2 100755
--- a/linphone/autogen.sh
+++ b/linphone/autogen.sh
@@ -1,8 +1,8 @@
 #!/bin/sh
 
-AM_VERSION="1.9"
+AM_VERSION="1.10"
 if ! type aclocal-$AM_VERSION 1>/dev/null 2>&1; then
 	# automake-1.9 (recommended) is not available on Fedora 8
 	AUTOMAKE=automake
 	ACLOCAL=aclocal
 else
@@ -10,16 +10,26 @@ else
 	AUTOMAKE=automake-${AM_VERSION}
 fi
 
+if test -f /opt/local/bin/glibtoolize ; then
+        # darwin
+        LIBTOOLIZE=/opt/local/bin/glibtoolize
+else
+        LIBTOOLIZE=libtoolize
+fi
+if test -d /opt/local/share/aclocal ; then
+        ACLOCAL_ARGS="-I /opt/local/share/aclocal"
+fi
+
+
 echo "Generating build scripts in linphone..."
 set -x
-libtoolize --copy --force
+$LIBTOOLIZE --copy --force
 
 /usr/bin/intltoolize -c --force --automake
-autoheader
-$ACLOCAL -I m4
+$ACLOCAL -I m4 $ACLOCAL_ARGS
 $AUTOMAKE --force-missing --add-missing --copy
+autoheader
 autoconf
-rm -rf config.cache
 
 echo "Generating build scripts in oRTP..."
 cd oRTP && ./autogen.sh && cd -
@@ -1,8 +1,8 @@
 if ! type aclocal-$AM_VERSION 1>/dev/null 2>&1; then
-	# automake-1.9 (recommended) is not available on Fedora 8
+	# automake-1.10 (recommended) is not available on Fedora 8
 	AUTOMAKE=automake
 	ACLOCAL=aclocal
diff --git a/linphone/mediastreamer2/autogen.sh b/linphone/mediastreamer2/autogen.sh
index 50299b9364..f88915e648 100755
--- a/linphone/mediastreamer2/autogen.sh
+++ b/linphone/mediastreamer2/autogen.sh
@@ -1,8 +1,8 @@
 #!/bin/sh
 
-AM_VERSION="1.9"
+AM_VERSION="1.10"
 if ! type aclocal-$AM_VERSION 1>/dev/null 2>&1; then
 	# automake-1.9 (recommended) is not available on Fedora 8
 	AUTOMAKE=automake
 	ACLOCAL=aclocal
 else
@@ -1,8 +1,8 @@
 if ! type aclocal-$AM_VERSION 1>/dev/null 2>&1; then
-	# automake-1.9 (recommended) is not available on Fedora 8
+	# automake-1.10 (recommended) is not available on Fedora 8
 	AUTOMAKE=automake
 	ACLOCAL=aclocal
diff --git a/linphone/oRTP/autogen.sh b/linphone/oRTP/autogen.sh
index 83085a0284..99302cbe4e 100755
--- a/linphone/oRTP/autogen.sh
+++ b/linphone/oRTP/autogen.sh
@@ -1,7 +1,7 @@
 #!/bin/sh
-AM_VERSION="1.9"
+AM_VERSION="1.10"
 if ! type aclocal-$AM_VERSION 1>/dev/null 2>&1; then
 	# automake-1.9 (recommended) is not available on Fedora 8
 	AUTOMAKE=automake
 	ACLOCAL=aclocal
 else
@@ -1,7 +1,7 @@
 if ! type aclocal-$AM_VERSION 1>/dev/null 2>&1; then
-	# automake-1.9 (recommended) is not available on Fedora 8
+	# automake-1.10 (recommended) is not available on Fedora 8
 	AUTOMAKE=automake
 	ACLOCAL=aclocal
-- 
GitLab